##############################################################################
#
# Copyright (c) 2008 Kapil Thangavelu
# All Rights Reserved.
#
# This software is subject to the provisions of the Zope Public License,
# Version 2.0 (ZPL).  A copy of the ZPL should accompany this distribution.
# THIS SOFTWARE IS PROVIDED "AS IS" AND ANY AND ALL EXPRESS OR IMPLIED
# WARRANTIES ARE DISCLAIMED, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
# WARRANTIES OF TITLE, MERCHANTABILITY, AGAINST INFRINGEMENT, AND FITNESS
# FOR A PARTICULAR PURPOSE.
#
##############################################################################
"""
$Id: $
"""

from zope.viewlet.viewlet import CSSViewlet

YahooDataTable = CSSViewlet('yui/build/datatable/assets/datatable.css')
YahooDataTableSkin = CSSViewlet('yui/build/assets/skins/sam/datatable.css')
YahooTreeView = CSSViewlet('yui/build/assets/skins/sam/treeview.css')
YahooLogger = CSSViewlet('yui/build/logger/assets/skins/sam/logger.css')
YahooGridCSS = CSSViewlet('yui/build/reset-fonts-grids/reset-fonts-grids.css')

