##############################################################################
#
# Copyright (c) 2008 Kapil Thangavelu
# All Rights Reserved.
#
# This software is subject to the provisions of the Zope Public License,
# Version 2.0 (ZPL).  A copy of the ZPL should accompany this distribution.
# THIS SOFTWARE IS PROVIDED "AS IS" AND ANY AND ALL EXPRESS OR IMPLIED
# WARRANTIES ARE DISCLAIMED, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
# WARRANTIES OF TITLE, MERCHANTABILITY, AGAINST INFRINGEMENT, AND FITNESS
# FOR A PARTICULAR PURPOSE.
#
##############################################################################
from zope.viewlet.viewlet import JavaScriptViewlet

YahooBase = JavaScriptViewlet('yui/yahoo/yahoo.js')
YahooEvent = JavaScriptViewlet('yui/event/event.js')
YahooConnection = JavaScriptViewlet('yui/connection/connection.js')
YahooDom = JavaScriptViewlet('yui/dom/dom.js')
YahooLogger = JavaScriptViewlet('yui/logger/logger-min.js')
YahooElement = JavaScriptViewlet('yui/element/element-beta.js')
YahooDataSource = JavaScriptViewlet('yui/datasource/datasource-beta.js')
YahooDataTable = JavaScriptViewlet('yui/datatable/datatable-beta.js')
YahooTree = JavaScriptViewlet('yui/treeview/treeview.js')
